export declare const Context: React.Context<ContextType>;
export declare const defaultHtmlFilter: HtmlFilter;
export declare const remarkLatexEnvironment: () => Transformer;
export declare type OutputType = {
    name?: string;
    ename?: string;
    evalue?: string;
    traceback?: string[];
    data?: {
        "text/plain"?: string[];
        "text/html"?: string[];
        "text/latex"?: string[];
        "image/png"?: string;
        "image/jpeg"?: string;
        "image/gif"?: string;
        "image/svg+xml"?: string;
        "application/javascript"?: string[];
    };
    output_type?: string;
    png?: string;
    jpeg?: string;
    gif?: string;
    svg?: string;
    text?: string[];
    execution_count?: number;
    metadata?: {
        scrolled?: boolean;
    };
};
export declare type CellType = {
    attachments?: {
        [s: string]: {
            [s: string]: string;
        };
    };
    cell_type?: string;
    execution_count?: number | null;
    prompt_number?: number;
    auto_number?: number;
    source?: string[];
    outputs?: OutputType[];
    input?: string[];
};
export declare type SyntaxThemeType = "atomDark" | "cb" | "coy" | "darcula" | "dark" | "duotoneDark" | "duotoneEarth" | "duotoneForest" | "duotoneLight" | "duotoneSea" | "duotoneSpace" | "funky" | "ghcolors" | "hopscotch" | "okaidia" | "pojoaque" | "prism" | "solarizedlight" | "tomorrow" | "twilight" | "vscDarkPlus" | "xonokai";
export declare type LanguageType = "python" | "r" | "julia" | "haskell" | "ruby";
export declare type HtmlFilter = (html: string) => string;
export declare type BaseProps = {
    ipynb: {
        cells: CellType[];
        worksheets?: {
            cells: CellType[];
        }[];
    };
    syntaxTheme?: SyntaxThemeType;
    language?: LanguageType;
    bgTransparent?: boolean;
    htmlFilter?: HtmlFilter;
    seqAsExecutionCount?: boolean;
};
export declare type MarkdownProps = {
    className: string;
    text: string;
};
export declare type ContextType = {
    syntaxTheme: SyntaxThemeType;
    language: LanguageType;
    bgTransparent: boolean;
    Markdown: React.FC<MarkdownProps>;
    htmlFilter: HtmlFilter;
    markdownOptions: any;
    seqAsExecutionCount: boolean;
};
export declare type Props = BaseProps & {
    markdownOptions?: MarkdownOptionsForKatex;
};
export declare const IpynbRenderer: React.FC<Props>;
export declare type CellProps = {
    cell: CellType;
    seq: number;
};
export declare const Cell: React.FC<CellProps>;
export declare type MarkdownOptionsForKatex = {
    remarkMath?: typeof defaultRemarkMath;
    remarkMathOptions?: RemarkMathOptions;
    katexOptions?: KatexOptions;
};
export declare const MarkdownForKatex: React.FC<MarkdownProps>;
export declare type MarkdownOptionsForMathjax = {
    remarkMath?: typeof defaultRemarkMath;
    remarkMathOptions?: RemarkMathOptions;
    mathjaxOptions?: MathJaxOptions;
};
export declare const MarkdownForMathjax: React.FC<MarkdownProps>;